@@ -5,8 +5,7 @@ module Fog
   module Compute
     class Aliyun
       class EipAddresses < Fog::Collection
-
-        model Fog::Compute::Aliyun::EipAddress 
+        model Fog::Compute::Aliyun::EipAddress
 
         def all(filters_arg = {})
           data = Fog::JSON.decode(service.list_eip_addresses(filters_arg).body)['EipAddresses']['EipAddress']
@@ -20,11 +19,10 @@ module Fog
 
         def get(allocation_id)
           if allocation_id
-            self.class.new(:service => service).all(:allocation_id => allocation_id)[0]
+            self.class.new(service: service).all(allocation_id: allocation_id)[0]
           end
         end
-
       end
     end
   end
-end
\ No newline at end of file
+end
