@@ -8,33 +8,27 @@ module Fog
         model Fog::Storage::Aliyun::Directory
 
         def all
-          containers = service.get_containers()
-          if nil == containers
-            return nil
-          end
-          data = Array.new
+          containers = service.get_containers
+          return nil if nil == containers
+          data = []
           i = 0
           containers.each do |entry|
-            key = entry["Prefix"][0]
+            key = entry['Prefix'][0]
             key[-1] = ''
-            data[i] = {:key=>key}
-            i = i + 1
+            data[i] = { key: key }
+            i += 1
           end
 
           load(data)
         end
 
         def get(key, options = {})
-          if key != nil && key != "" && key != '.'
-            dir = key+'/'
+          if !key.nil? && key != '' && key != '.'
+            dir = key + '/'
             ret = service.head_object(dir, options)
-            if ret.data[:status] == 200
-              new(:key => key)
-            else
-              nil
-            end
+            new(key: key) if ret.data[:status] == 200
           else
-            new(:key => "")
+            new(key: '')
           end
         rescue Fog::Storage::Aliyun::NotFound
           nil
