@@ -9,18 +9,18 @@ module Fog
         #
         def delete_bucket(bucket)
           location = get_bucket_location(bucket)
-          endpoint = "http://"+location+".aliyuncs.com"
-          resource = bucket+'/'
+          endpoint = 'http://' + location + '.aliyuncs.com'
+          resource = bucket + '/'
           request(
-            :expects  => 204,
-            :method   => 'DELETE',
-            :bucket   => bucket,
-            :resource => resource,
-            :endpoint => endpoint
+            expects: 204,
+            method: 'DELETE',
+            bucket: bucket,
+            resource: resource,
+            endpoint: endpoint
           )
         end
       end
-      
+
       class Mock
         def delete_bucket(bucket)
         end
